@@ -1,17 +1,5 @@
 my $title = translate('editTranslation');
-my %parameter = (
-                 path   => $m_hrSettings->{cgi}{bin} . '/templates',
-                 style  => $m_sStyle,
-                 title  => $title,
-                 server => $m_hrSettings->{cgi}{serverName},
-                 id     => "editTranslation",
-                 class  => 'min',
-);
-my $window = new HTML::Window(\%parameter);
-$window->set_closeable(0);
-$window->set_moveable(0);
-$window->set_resizeable(0);
-$m_sContent .= $window->windowHeader();
+print '<div class="ShowTables" style="margin-top:1.65em">';
 
 loadTranslate($m_hrSettings->{translate});
 *m_hrLng = \$MySQL::Admin::Translate::lang;
@@ -19,8 +7,10 @@ my @l;
 foreach my $key (sort keys %{$m_hrLng}) {
     push @l, $key;
 }
-$m_sContent .= start_form(-method => "POST",
-                          -action => "$ENV{SCRIPT_NAME}",)
+my $txt = translate('translate');
+print start_form(-method => "POST",
+                          -onSubmit => "submitForm(this,'$m_sAction','$txt');return false;",
+                          -action => $ENV{SCRIPT_NAME})
   . hidden({-name => 'action'}, 'showaddTranslation')
   . hidden(
            {
@@ -97,13 +87,13 @@ if (param('do')) {
     my $lgn = param('lang');
     unless (defined $m_hrLng->{$lgn}{$key}) {
         $m_hrLng->{$lgn}{$key} = $txt;
-        $m_sContent .= "Translation added $lgn<br/>$key:  $m_hrLng->{$lgn}{$key}<br/>";
+        print "Translation added $lgn<br/>$key:  $m_hrLng->{$lgn}{$key}<br/>";
         saveTranslate($m_hrSettings->{translate});
         loadTranslate($m_hrSettings->{translate});
     } else {
-        $m_sContent .= "Key already defined<br/>$key:  $m_hrLng->{$lgn}{$key}<br/>";
+        print "Key already defined<br/>$key:  $m_hrLng->{$lgn}{$key}<br/>";
     }
 
 }
-$m_sContent .= $window->windowFooter();
+print '</div>';
 1;
