@@ -1,46 +1,46 @@
 $VAR1 = {
-          'admin' => {
-                       'password' => 'testpass'
-                     },
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'mod' => 1,
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'version' => '0.89',
+          'floodtime' => 10,
+          'language' => 'en',
           'cgi' => {
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'title' => 'MySQL::Admin',
-                     'alias' => 'perl',
-                     'bin' => '/var/www/cgi-bin',
                      'cookiePath' => '/',
+                     'bin' => '/var/www/cgi-bin',
                      'expires' => '+1y',
                      'style' => 'mysql',
+                     'alias' => 'cgi-bin',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'title' => 'MySQL::Admin',
                      'serverName' => 'localhost'
                    },
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'scriptAlias' => 'perl',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
           'database' => {
-                          'CurrentPass' => 'keinz',
                           'CurrentHost' => 'localhost',
-                          'host' => 'localhost',
                           'name' => 'LZE',
+                          'CurrentPass' => 'keinz',
                           'CurrentUser' => 'root',
                           'CurrentDb' => 'LZE',
                           'user' => 'root',
+                          'host' => 'localhost',
                           'password' => 'keinz'
                         },
-          'floodtime' => 10,
+          'version' => '0.9',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'mod' => 0,
+          'admin' => {
+                       'password' => 'testpass'
+                     },
           'files' => {
                        'owner' => 'lze',
                        'group' => 'lze',
                        'chmod' => '0755'
                      },
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'scriptAlias' => 'cgi-bin',
           'uploads' => {
+                         'path' => '/var/www/htdocs/download',
                          'chmod' => 438,
-                         'maxlength' => 21000000,
-                         'path' => '/var/www/htdocs/download'
-                       },
-          'language' => 'en'
+                         'maxlength' => 21000000
+                       }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
