@@ -1,7 +1,6 @@
-use utf8;
 use lib qw(/var/www/cgi-bin/lib);
-##################################################################################
-#      path is set during make                                                    #
+###############################################################################
+#      path is set during make                                                #
 ###############################################################################
 use MySQL::Admin qw(:all);
 use MySQL::Admin::Settings;
